@@ -1,6 +1,6 @@
 """Help command for indexing available commands."""
 
-from argparse import ArgumentParser
+from configargparse import ArgumentParser
 from typing import Sequence
 
 from ..version import __version__
@@ -31,5 +31,10 @@ def execute(argv: Sequence[str] = None):
         parser.print_help()
 
 
-if __name__ == "__main__":
-    execute()
+def main():
+    """Execute the main line."""
+    if __name__ == "__main__":
+        execute()
+
+
+main()
