@@ -1,5 +1,5 @@
 import itertools
-from argparse import ArgumentParser, ArgumentTypeError
+from configargparse import ArgumentParser, ArgumentTypeError, YAMLConfigFileParser
 
 from asynctest import TestCase as AsyncTestCase, mock as async_mock
 
@@ -10,7 +10,7 @@ from ..util import ByteSize
 class TestArgParse(AsyncTestCase):
     async def test_groups(self):
         """Test optional argument parsing."""
-        parser = ArgumentParser()
+        parser = argparse.create_argument_parser()
 
         groups = (
             g
@@ -24,12 +24,12 @@ class TestArgParse(AsyncTestCase):
     async def test_transport_settings(self):
         """Test required argument parsing."""
 
-        parser = ArgumentParser()
+        parser = argparse.create_argument_parser()
         group = argparse.TransportGroup()
         group.add_arguments(parser)
 
         with async_mock.patch.object(parser, "exit") as exit_parser:
-            parser.parse_args([])
+            parser.parse_args(["-h"])
             exit_parser.assert_called_once()
 
         result = parser.parse_args(
@@ -54,6 +54,53 @@ class TestArgParse(AsyncTestCase):
         assert settings.get("transport.outbound_configs") == ["http"]
         assert result.max_outbound_retry == 5
 
+    async def test_general_settings_file(self):
+        """Test file argument parsing."""
+
+        parser = argparse.create_argument_parser()
+        group = argparse.GeneralGroup()
+        group.add_arguments(parser)
+
+        with async_mock.patch.object(parser, "exit") as exit_parser:
+            parser.parse_args(["-h"])
+            exit_parser.assert_called_once()
+
+        result = parser.parse_args(
+            [
+                "--arg-file",
+                "./aries_cloudagent/config/tests/test-general-args.yaml",
+            ]
+        )
+
+        assert result.external_plugins == ["foo"]
+        assert result.storage_type == "bar"
+
+        settings = group.get_settings(result)
+
+        assert settings.get("external_plugins") == ["foo"]
+        assert settings.get("storage_type") == "bar"
+
+    async def test_transport_settings_file(self):
+        """Test file argument parsing."""
+
+        parser = argparse.create_argument_parser()
+        group = argparse.GeneralGroup()
+        group.add_arguments(parser)
+        group = argparse.TransportGroup()
+        group.add_arguments(parser)
+
+        with async_mock.patch.object(parser, "exit") as exit_parser:
+            parser.parse_args(["-h"])
+            exit_parser.assert_called_once()
+
+        result = parser.parse_args(
+            [
+                "--arg-file",
+                "./aries_cloudagent/config/tests/test-transport-args.yaml",
+            ]
+        )
+        # no asserts, just testing that the parser doesn't fail
+
     def test_bytesize(self):
         bs = ByteSize()
         with self.assertRaises(ArgumentTypeError):
