@@ -4,11 +4,14 @@ import json
 
 from aiohttp import web
 from aiohttp_apispec import docs, match_info_schema, querystring_schema, response_schema
-from marshmallow import fields, Schema
+from marshmallow import fields
 
-from .base import BaseHolder, HolderError
+from ..ledger.base import BaseLedger
+from ..ledger.error import LedgerError
+from ..messaging.models.openapi import OpenAPISchema
 from ..messaging.valid import (
     INDY_CRED_DEF_ID,
+    INDY_CRED_REV_ID,
     INDY_REV_REG_ID,
     INDY_SCHEMA_ID,
     INDY_WQL,
@@ -17,43 +20,22 @@ from ..messaging.valid import (
     UUIDFour,
 )
 from ..wallet.error import WalletNotFoundError
+from .base import BaseHolder, HolderError
 
 
-class AttributeMimeTypesResultSchema(Schema):
+class AttributeMimeTypesResultSchema(OpenAPISchema):
     """Result schema for credential attribute MIME type."""
 
 
-class RawEncCredAttrSchema(Schema):
-    """Credential attribute schema."""
+class CredBriefSchema(OpenAPISchema):
+    """Result schema with credential brief for a credential query."""
 
-    raw = fields.Str(description="Raw value", example="Alex")
-    encoded = fields.Str(
-        description="(Numeric string) encoded value",
-        example="412821674062189604125602903860586582569826459817431467861859655321",
+    referent = fields.Str(description="Credential referent", example=UUIDFour.EXAMPLE)
+    attrs = fields.Dict(
+        keys=fields.Str(description="Attribute name"),
+        values=fields.Str(description="Attribute value"),
+        description="Attribute names mapped to their raw values",
     )
-
-
-class RevRegSchema(Schema):
-    """Revocation registry schema."""
-
-    accum = fields.Str(
-        description="Revocation registry accumulator state",
-        example="21 136D54EA439FC26F03DB4b812 21 123DE9F624B86823A00D ...",
-    )
-
-
-class WitnessSchema(Schema):
-    """Witness schema."""
-
-    omega = fields.Str(
-        description="Revocation registry witness omega state",
-        example="21 129EA8716C921058BB91826FD 21 8F19B91313862FE916C0 ...",
-    )
-
-
-class CredentialSchema(Schema):
-    """Result schema for a credential query."""
-
     schema_id = fields.Str(description="Schema identifier", **INDY_SCHEMA_ID)
     cred_def_id = fields.Str(
         description="Credential definition identifier", **INDY_CRED_DEF_ID
@@ -61,34 +43,38 @@ class CredentialSchema(Schema):
     rev_reg_id = fields.Str(
         description="Revocation registry identifier", **INDY_REV_REG_ID
     )
-    values = fields.Dict(
-        keys=fields.Str(description="Attribute name"),
-        values=fields.Nested(RawEncCredAttrSchema),
-        description="Attribute names mapped to their raw and encoded values",
+    cred_rev_id = fields.Str(
+        description="Credential revocation identifier", **INDY_CRED_REV_ID
     )
-    signature = fields.Dict(description="Digital signature")
-    signature_correctness_proof = fields.Dict(description="Signature correctness proof")
-    rev_reg = fields.Nested(RevRegSchema)
-    witness = fields.Nested(WitnessSchema)
 
 
-class CredentialsListSchema(Schema):
+class CredBriefListSchema(OpenAPISchema):
     """Result schema for a credential query."""
 
-    results = fields.List(fields.Nested(CredentialSchema()))
+    results = fields.List(fields.Nested(CredBriefSchema()))
 
 
-class CredentialsListQueryStringSchema(Schema):
+class CredentialsListQueryStringSchema(OpenAPISchema):
     """Parameters and validators for query string in credentials list query."""
 
-    start = fields.Int(description="Start index", required=False, **WHOLE_NUM,)
+    start = fields.Int(
+        description="Start index",
+        required=False,
+        **WHOLE_NUM,
+    )
     count = fields.Int(
-        description="Maximum number to retrieve", required=False, **NATURAL_NUM,
+        description="Maximum number to retrieve",
+        required=False,
+        **NATURAL_NUM,
+    )
+    wql = fields.Str(
+        description="(JSON) WQL query",
+        required=False,
+        **INDY_WQL,
     )
-    wql = fields.Str(description="(JSON) WQL query", required=False, **INDY_WQL,)
 
 
-class CredIdMatchInfoSchema(Schema):
+class CredIdMatchInfoSchema(OpenAPISchema):
     """Path parameters and validators for request taking credential id."""
 
     credential_id = fields.Str(
@@ -96,9 +82,15 @@ class CredIdMatchInfoSchema(Schema):
     )
 
 
+class CredRevokedResultSchema(OpenAPISchema):
+    """Result schema for credential revoked request."""
+
+    revoked = fields.Bool(description="Whether credential is revoked on the ledger")
+
+
 @docs(tags=["credentials"], summary="Fetch a credential from wallet by id")
 @match_info_schema(CredIdMatchInfoSchema())
-@response_schema(CredentialSchema(), 200)
+@response_schema(CredBriefSchema(), 200)
 async def credentials_get(request: web.BaseRequest):
     """
     Request handler for retrieving a credential.
@@ -124,6 +116,43 @@ async def credentials_get(request: web.BaseRequest):
     return web.json_response(credential_json)
 
 
+@docs(tags=["credentials"], summary="Query credential revocation status by id")
+@match_info_schema(CredIdMatchInfoSchema())
+@response_schema(CredRevokedResultSchema(), 200)
+async def credentials_revoked(request: web.BaseRequest):
+    """
+    Request handler for querying revocation status of credential.
+
+    Args:
+        request: aiohttp request object
+
+    Returns:
+        The credential response
+
+    """
+    context = request.app["request_context"]
+
+    credential_id = request.match_info["credential_id"]
+
+    ledger: BaseLedger = await context.inject(BaseLedger, required=False)
+    if not ledger:
+        reason = "No ledger available"
+        if not context.settings.get_value("wallet.type"):
+            reason += ": missing wallet-type?"
+        raise web.HTTPForbidden(reason=reason)
+
+    async with ledger:
+        try:
+            holder: BaseHolder = await context.inject(BaseHolder)
+            revoked = await holder.credential_revoked(credential_id, ledger)
+        except WalletNotFoundError as err:
+            raise web.HTTPNotFound(reason=err.roll_up) from err
+        except LedgerError as err:
+            raise web.HTTPBadRequest(reason=err.roll_up) from err
+
+    return web.json_response({"revoked": revoked})
+
+
 @docs(tags=["credentials"], summary="Get attribute MIME types from wallet")
 @match_info_schema(CredIdMatchInfoSchema())
 @response_schema(AttributeMimeTypesResultSchema(), 200)
@@ -172,10 +201,11 @@ async def credentials_remove(request: web.BaseRequest):
 
 
 @docs(
-    tags=["credentials"], summary="Fetch credentials from wallet",
+    tags=["credentials"],
+    summary="Fetch credentials from wallet",
 )
 @querystring_schema(CredentialsListQueryStringSchema())
-@response_schema(CredentialsListSchema(), 200)
+@response_schema(CredBriefListSchema(), 200)
 async def credentials_list(request: web.BaseRequest):
     """
     Request handler for searching credential records.
@@ -215,12 +245,17 @@ async def register(app: web.Application):
     app.add_routes(
         [
             web.get("/credential/{credential_id}", credentials_get, allow_head=False),
+            web.get(
+                "/credential/revoked/{credential_id}",
+                credentials_revoked,
+                allow_head=False,
+            ),
             web.get(
                 "/credential/mime-types/{credential_id}",
                 credentials_attr_mime_types_get,
                 allow_head=False,
             ),
-            web.post("/credential/{credential_id}/remove", credentials_remove),
+            web.delete("/credential/{credential_id}", credentials_remove),
             web.get("/credentials", credentials_list, allow_head=False),
         ]
     )
