@@ -4,8 +4,10 @@ import pytest
 
 from ...config.injection_context import InjectionContext
 from ...ledger.base import BaseLedger
+from ...ledger.endpoint_type import EndpointType
 
 from .. import routes as test_module
+from ..indy import Role
 
 
 class TestLedgerRoutes(AsyncTestCase):
@@ -21,14 +23,21 @@ class TestLedgerRoutes(AsyncTestCase):
         self.test_did = "did"
         self.test_verkey = "verkey"
         self.test_endpoint = "http://localhost:8021"
+        self.test_endpoint_type = EndpointType.PROFILE
+        self.test_endpoint_type_profile = "http://company.com/profile"
 
     async def test_missing_ledger(self):
-        request = async_mock.MagicMock(app=self.app,)
+        request = async_mock.MagicMock(
+            app=self.app,
+        )
         self.context.injector.clear_binding(BaseLedger)
 
         with self.assertRaises(test_module.web.HTTPForbidden):
             await test_module.register_ledger_nym(request)
 
+        with self.assertRaises(test_module.web.HTTPForbidden):
+            await test_module.get_nym_role(request)
+
         with self.assertRaises(test_module.web.HTTPForbidden):
             await test_module.rotate_public_did_keypair(request)
 
@@ -89,6 +98,25 @@ class TestLedgerRoutes(AsyncTestCase):
             )
             assert result is json_response.return_value
 
+    async def test_get_endpoint_of_type_profile(self):
+        request = async_mock.MagicMock()
+        request.app = self.app
+        request.query = {
+            "did": self.test_did,
+            "endpoint_type": self.test_endpoint_type.w3c,
+        }
+        with async_mock.patch.object(
+            test_module.web, "json_response", async_mock.Mock()
+        ) as json_response:
+            self.ledger.get_endpoint_for_did.return_value = (
+                self.test_endpoint_type_profile
+            )
+            result = await test_module.get_did_endpoint(request)
+            json_response.assert_called_once_with(
+                {"endpoint": self.ledger.get_endpoint_for_did.return_value}
+            )
+            assert result is json_response.return_value
+
     async def test_get_endpoint_no_did(self):
         request = async_mock.MagicMock()
         request.app = self.app
@@ -107,7 +135,11 @@ class TestLedgerRoutes(AsyncTestCase):
     async def test_register_nym(self):
         request = async_mock.MagicMock(
             app=self.app,
-            query={"did": self.test_did, "verkey": self.test_verkey, "role": "reset",},
+            query={
+                "did": self.test_did,
+                "verkey": self.test_verkey,
+                "role": "reset",
+            },
         )
         with async_mock.patch.object(
             test_module.web, "json_response", async_mock.Mock()
@@ -136,6 +168,70 @@ class TestLedgerRoutes(AsyncTestCase):
         with self.assertRaises(test_module.web.HTTPForbidden):
             await test_module.register_ledger_nym(request)
 
+    async def test_register_nym_ledger_error(self):
+        request = async_mock.MagicMock()
+        request.app = self.app
+        request.query = {"did": self.test_did, "verkey": self.test_verkey}
+        self.ledger.register_nym.side_effect = test_module.LedgerError("Error")
+        with self.assertRaises(test_module.web.HTTPBadRequest):
+            await test_module.register_ledger_nym(request)
+
+    async def test_register_nym_wallet_error(self):
+        request = async_mock.MagicMock()
+        request.app = self.app
+        request.query = {"did": self.test_did, "verkey": self.test_verkey}
+        self.ledger.register_nym.side_effect = test_module.WalletError("Error")
+        with self.assertRaises(test_module.web.HTTPBadRequest):
+            await test_module.register_ledger_nym(request)
+
+    async def test_get_nym_role(self):
+        request = async_mock.MagicMock()
+        request.app = self.app
+        request.query = {"did": self.test_did}
+
+        with async_mock.patch.object(
+            test_module.web, "json_response", async_mock.Mock()
+        ) as json_response:
+            self.ledger.get_nym_role.return_value = Role.USER
+            result = await test_module.get_nym_role(request)
+            json_response.assert_called_once_with({"role": "USER"})
+            assert result is json_response.return_value
+
+    async def test_get_nym_role_bad_request(self):
+        request = async_mock.MagicMock()
+        request.app = self.app
+        request.query = {"no": "did"}
+        with self.assertRaises(test_module.web.HTTPBadRequest):
+            await test_module.get_nym_role(request)
+
+    async def test_get_nym_role_ledger_txn_error(self):
+        request = async_mock.MagicMock()
+        request.app = self.app
+        request.query = {"did": self.test_did}
+        self.ledger.get_nym_role.side_effect = test_module.LedgerTransactionError(
+            "Error in building get-nym request"
+        )
+        with self.assertRaises(test_module.web.HTTPForbidden):
+            await test_module.get_nym_role(request)
+
+    async def test_get_nym_role_bad_ledger_req(self):
+        request = async_mock.MagicMock()
+        request.app = self.app
+        request.query = {"did": self.test_did}
+        self.ledger.get_nym_role.side_effect = test_module.BadLedgerRequestError(
+            "No such public DID"
+        )
+        with self.assertRaises(test_module.web.HTTPNotFound):
+            await test_module.get_nym_role(request)
+
+    async def test_get_nym_role_ledger_error(self):
+        request = async_mock.MagicMock()
+        request.app = self.app
+        request.query = {"did": self.test_did}
+        self.ledger.get_nym_role.side_effect = test_module.LedgerError("Error")
+        with self.assertRaises(test_module.web.HTTPBadRequest):
+            await test_module.get_nym_role(request)
+
     async def test_rotate_public_did_keypair(self):
         request = async_mock.MagicMock()
         request.app = self.app
@@ -175,7 +271,7 @@ class TestLedgerRoutes(AsyncTestCase):
         with async_mock.patch.object(
             test_module.web, "json_response", async_mock.Mock()
         ) as json_response:
-            self.ledger.LEDGER_TYPE = "indy"
+            self.ledger.type = "indy"
             self.ledger.get_txn_author_agreement.return_value = {"taa_required": False}
             self.ledger.get_latest_txn_author_acceptance.return_value = None
             result = await test_module.ledger_get_taa(request)
@@ -196,7 +292,7 @@ class TestLedgerRoutes(AsyncTestCase):
         with async_mock.patch.object(
             test_module.web, "json_response", async_mock.Mock()
         ) as json_response:
-            self.ledger.LEDGER_TYPE = "indy"
+            self.ledger.type = "indy"
             self.ledger.get_txn_author_agreement.return_value = taa_info
             self.ledger.get_latest_txn_author_acceptance.return_value = accepted
             result = await test_module.ledger_get_taa(request)
@@ -208,7 +304,7 @@ class TestLedgerRoutes(AsyncTestCase):
         request = async_mock.MagicMock()
         request.app = self.app
 
-        self.ledger.LEDGER_TYPE = "indy"
+        self.ledger.type = "indy"
         self.ledger.get_txn_author_agreement.side_effect = test_module.LedgerError()
 
         with self.assertRaises(test_module.web.HTTPBadRequest):
@@ -226,7 +322,7 @@ class TestLedgerRoutes(AsyncTestCase):
         )
 
         with self.assertRaises(test_module.web.HTTPBadRequest):
-            self.ledger.LEDGER_TYPE = "indy"
+            self.ledger.type = "indy"
             self.ledger.get_txn_author_agreement.return_value = {"taa_required": False}
             await test_module.ledger_accept_taa(request)
 
@@ -244,7 +340,7 @@ class TestLedgerRoutes(AsyncTestCase):
         with async_mock.patch.object(
             test_module.web, "json_response", async_mock.Mock()
         ) as json_response:
-            self.ledger.LEDGER_TYPE = "indy"
+            self.ledger.type = "indy"
             self.ledger.get_txn_author_agreement.return_value = {"taa_required": True}
             result = await test_module.ledger_accept_taa(request)
             json_response.assert_called_once_with({})
@@ -262,7 +358,7 @@ class TestLedgerRoutes(AsyncTestCase):
         request = async_mock.MagicMock()
         request.app = self.app
 
-        self.ledger.LEDGER_TYPE = "not-indy"
+        self.ledger.type = "not-indy"
         with self.assertRaises(test_module.web.HTTPForbidden):
             await test_module.ledger_accept_taa(request)
 
@@ -276,7 +372,7 @@ class TestLedgerRoutes(AsyncTestCase):
                 "mechanism": "mechanism",
             }
         )
-        self.ledger.LEDGER_TYPE = "indy"
+        self.ledger.type = "indy"
         self.ledger.get_txn_author_agreement.return_value = {"taa_required": True}
         self.ledger.accept_txn_author_agreement.side_effect = test_module.StorageError()
         with self.assertRaises(test_module.web.HTTPBadRequest):
