@@ -5,6 +5,7 @@ from typing import Mapping, Union
 import uuid
 
 from marshmallow import (
+    EXCLUDE,
     fields,
     pre_load,
     post_load,
@@ -13,6 +14,7 @@ from marshmallow import (
     ValidationError,
 )
 
+from ..protocols.didcomm_prefix import DIDCommPrefix
 from ..wallet.base import BaseWallet
 
 from .decorators.base import BaseDecoratorSet
@@ -61,7 +63,7 @@ class AgentMessage(BaseModel):
             TypeError: If message type is missing on subclass Meta class
 
         """
-        super(AgentMessage, self).__init__()
+        super().__init__()
         if _id:
             self._message_id = _id
             self._message_new_id = False
@@ -111,10 +113,10 @@ class AgentMessage(BaseModel):
         Accessor for the message type identifier.
 
         Returns:
-            Message type defined on `Meta.message_type`
+            Current DIDComm prefix, slash, message type defined on `Meta.message_type`
 
         """
-        return self.Meta.message_type
+        return DIDCommPrefix.qualify_current(self.Meta.message_type)
 
     @property
     def _id(self) -> str:
@@ -265,7 +267,10 @@ class AgentMessage(BaseModel):
         Args:
             val: ThreadDecorator or dict to set as the thread
         """
-        self._decorators["thread"] = val
+        if val is None:
+            self._decorators.pop("thread", None)
+        else:
+            self._decorators["thread"] = val
 
     @property
     def _thread_id(self) -> str:
@@ -319,7 +324,10 @@ class AgentMessage(BaseModel):
         Args:
             val: TraceDecorator or dict to set as the trace
         """
-        self._decorators["trace"] = val
+        if val is None:
+            self._decorators.pop("trace", None)
+        else:
+            self._decorators["trace"] = val
 
     def assign_trace_from(self, msg: "AgentMessage"):
         """
@@ -384,6 +392,7 @@ class AgentMessageSchema(BaseModelSchema):
 
         model_class = None
         signed_fields = None
+        unknown = EXCLUDE
 
     # Avoid clobbering keywords
     _type = fields.Str(
@@ -391,7 +400,7 @@ class AgentMessageSchema(BaseModelSchema):
         dump_only=True,
         required=False,
         description="Message type",
-        example="did:sov:BzCbsNYhMrjHiqZDTUASHg;spec/my-family/1.0/my-message-type",
+        example="https://didcomm.org/my-family/1.0/my-message-type",
     )
     _id = fields.Str(
         data_key="@id",
@@ -408,13 +417,7 @@ class AgentMessageSchema(BaseModelSchema):
             TypeError: If Meta.model_class has not been set
 
         """
-        super(AgentMessageSchema, self).__init__(*args, **kwargs)
-        if not self.Meta.model_class:
-            raise TypeError(
-                "Can't instantiate abstract class {} with no model_class".format(
-                    self.__class__.__name__
-                )
-            )
+        super().__init__(*args, **kwargs)
         self._decorators = DecoratorSet()
         self._decorators_dict = None
         self._signatures = {}
