@@ -332,7 +332,9 @@ class AttachDecoratorData(BaseModel):
         return getattr(self, "sha256_", None)
 
     async def sign(
-        self, verkeys: Union[str, Sequence[str]], wallet: BaseWallet,
+        self,
+        verkeys: Union[str, Sequence[str]],
+        wallet: BaseWallet,
     ):
         """
         Sign base64 data value of attachment.
@@ -669,4 +671,7 @@ class AttachDecoratorSchema(BaseModelSchema):
         example="view from doorway, facing east, with lights off",
         required=False,
     )
-    data = fields.Nested(AttachDecoratorDataSchema, required=True,)
+    data = fields.Nested(
+        AttachDecoratorDataSchema,
+        required=True,
+    )
