@@ -11,32 +11,40 @@ from aiohttp_apispec import (
     response_schema,
 )
 
-from marshmallow import fields, Schema
+from marshmallow import fields
 from marshmallow.validate import Regexp
 
 from ...issuer.base import BaseIssuer, IssuerError
 from ...ledger.base import BaseLedger
 from ...ledger.error import LedgerError
 from ...storage.base import BaseStorage
+from ..models.openapi import OpenAPISchema
 from ..valid import B58, NATURAL_NUM, INDY_SCHEMA_ID, INDY_VERSION
 from .util import SchemaQueryStringSchema, SCHEMA_SENT_RECORD_TYPE, SCHEMA_TAGS
 
 
-class SchemaSendRequestSchema(Schema):
+class SchemaSendRequestSchema(OpenAPISchema):
     """Request schema for schema send request."""
 
-    schema_name = fields.Str(required=True, description="Schema name", example="prefs",)
+    schema_name = fields.Str(
+        required=True,
+        description="Schema name",
+        example="prefs",
+    )
     schema_version = fields.Str(
         required=True, description="Schema version", **INDY_VERSION
     )
     attributes = fields.List(
-        fields.Str(description="attribute name", example="score",),
+        fields.Str(
+            description="attribute name",
+            example="score",
+        ),
         required=True,
         description="List of schema attributes",
     )
 
 
-class SchemaSendResultsSchema(Schema):
+class SchemaSendResultsSchema(OpenAPISchema):
     """Results schema for schema send request."""
 
     schema_id = fields.Str(
@@ -45,30 +53,34 @@ class SchemaSendResultsSchema(Schema):
     schema = fields.Dict(description="Schema result", required=True)
 
 
-class SchemaSchema(Schema):
+class SchemaSchema(OpenAPISchema):
     """Content for returned schema."""
 
     ver = fields.Str(description="Node protocol version", **INDY_VERSION)
     ident = fields.Str(data_key="id", description="Schema identifier", **INDY_SCHEMA_ID)
     name = fields.Str(
-        description="Schema name", example=INDY_SCHEMA_ID["example"].split(":")[2],
+        description="Schema name",
+        example=INDY_SCHEMA_ID["example"].split(":")[2],
     )
     version = fields.Str(description="Schema version", **INDY_VERSION)
     attr_names = fields.List(
-        fields.Str(description="Attribute name", example="score",),
+        fields.Str(
+            description="Attribute name",
+            example="score",
+        ),
         description="Schema attribute names",
         data_key="attrNames",
     )
     seqNo = fields.Int(description="Schema sequence number", **NATURAL_NUM)
 
 
-class SchemaGetResultsSchema(Schema):
+class SchemaGetResultsSchema(OpenAPISchema):
     """Results schema for schema get request."""
 
-    schema_json = fields.Nested(SchemaSchema())
+    schema = fields.Nested(SchemaSchema())
 
 
-class SchemasCreatedResultsSchema(Schema):
+class SchemasCreatedResultsSchema(OpenAPISchema):
     """Results schema for a schemas-created request."""
 
     schema_ids = fields.List(
@@ -76,7 +88,7 @@ class SchemasCreatedResultsSchema(Schema):
     )
 
 
-class SchemaIdMatchInfoSchema(Schema):
+class SchemaIdMatchInfoSchema(OpenAPISchema):
     """Path parameters and validators for request taking schema id."""
 
     schema_id = fields.Str(
@@ -131,7 +143,8 @@ async def schemas_send_schema(request: web.BaseRequest):
 
 
 @docs(
-    tags=["schema"], summary="Search for matching schema that agent originated",
+    tags=["schema"],
+    summary="Search for matching schema that agent originated",
 )
 @querystring_schema(SchemaQueryStringSchema())
 @response_schema(SchemasCreatedResultsSchema(), 200)
