@@ -2,7 +2,7 @@
 
 from typing import Sequence
 
-from aries_cloudagent.config.injection_context import InjectionContext
+from ....config.injection_context import InjectionContext
 
 from .base_service import BaseMenuService
 
