@@ -44,13 +44,23 @@ def did_doc():
     ident = "1"
     pk_value = TEST_VERKEY
     pk = PublicKey(
-        TEST_DID, ident, pk_value, PublicKeyType.ED25519_SIG_2018, controller, False,
+        TEST_DID,
+        ident,
+        pk_value,
+        PublicKeyType.ED25519_SIG_2018,
+        controller,
+        False,
     )
     doc.set(pk)
     recip_keys = [pk]
     router_keys = []
     service = Service(
-        TEST_DID, "indy", "IndyAgent", recip_keys, router_keys, TEST_ENDPOINT,
+        TEST_DID,
+        "indy",
+        "IndyAgent",
+        recip_keys,
+        router_keys,
+        TEST_ENDPOINT,
     )
     doc.set(service)
     yield doc
