@@ -108,7 +108,11 @@ class ConnectionStaticResultSchema(OpenAPISchema):
 class ConnectionsListQueryStringSchema(OpenAPISchema):
     """Parameters and validators for connections list request query string."""
 
-    alias = fields.Str(description="Alias", required=False, example="Barry",)
+    alias = fields.Str(
+        description="Alias",
+        required=False,
+        example="Barry",
+    )
     initiator = fields.Str(
         description="Connection initiator",
         required=False,
@@ -140,7 +144,11 @@ class ConnectionsListQueryStringSchema(OpenAPISchema):
 class CreateInvitationQueryStringSchema(OpenAPISchema):
     """Parameters and validators for create invitation request query string."""
 
-    alias = fields.Str(description="Alias", required=False, example="Barry",)
+    alias = fields.Str(
+        description="Alias",
+        required=False,
+        example="Barry",
+    )
     auto_accept = fields.Boolean(
         description="Auto-accept connection (default as per configuration)",
         required=False,
@@ -156,7 +164,11 @@ class CreateInvitationQueryStringSchema(OpenAPISchema):
 class ReceiveInvitationQueryStringSchema(OpenAPISchema):
     """Parameters and validators for receive invitation request query string."""
 
-    alias = fields.Str(description="Alias", required=False, example="Barry",)
+    alias = fields.Str(
+        description="Alias",
+        required=False,
+        example="Barry",
+    )
     auto_accept = fields.Boolean(
         description="Auto-accept connection (defaults to configuration)",
         required=False,
@@ -212,7 +224,8 @@ def connection_sort_key(conn):
 
 
 @docs(
-    tags=["connection"], summary="Query agent-to-agent connections",
+    tags=["connection"],
+    summary="Query agent-to-agent connections",
 )
 @querystring_schema(ConnectionsListQueryStringSchema())
 @response_schema(ConnectionListSchema(), 200)
@@ -284,7 +297,8 @@ async def connections_retrieve(request: web.BaseRequest):
 
 
 @docs(
-    tags=["connection"], summary="Create a new connection invitation",
+    tags=["connection"],
+    summary="Create a new connection invitation",
 )
 @querystring_schema(CreateInvitationQueryStringSchema())
 @response_schema(InvitationResultSchema(), 200)
@@ -332,7 +346,8 @@ async def connections_create_invitation(request: web.BaseRequest):
 
 
 @docs(
-    tags=["connection"], summary="Receive a new connection invitation",
+    tags=["connection"],
+    summary="Receive a new connection invitation",
 )
 @querystring_schema(ReceiveInvitationQueryStringSchema())
 @request_schema(ReceiveInvitationRequestSchema())
@@ -371,7 +386,8 @@ async def connections_receive_invitation(request: web.BaseRequest):
 
 
 @docs(
-    tags=["connection"], summary="Accept a stored connection invitation",
+    tags=["connection"],
+    summary="Accept a stored connection invitation",
 )
 @match_info_schema(ConnIdMatchInfoSchema())
 @querystring_schema(AcceptInvitationQueryStringSchema())
@@ -408,7 +424,8 @@ async def connections_accept_invitation(request: web.BaseRequest):
 
 
 @docs(
-    tags=["connection"], summary="Accept a stored connection request",
+    tags=["connection"],
+    summary="Accept a stored connection request",
 )
 @match_info_schema(ConnIdMatchInfoSchema())
 @querystring_schema(AcceptRequestQueryStringSchema())
@@ -565,7 +582,7 @@ async def register(app: web.Application):
                 "/connections/{conn_id}/establish-inbound/{ref_id}",
                 connections_establish_inbound,
             ),
-            web.post("/connections/{conn_id}/remove", connections_remove),
+            web.delete("/connections/{conn_id}", connections_remove),
         ]
     )
 
