@@ -401,6 +401,20 @@ class TestConnectionManager(AsyncTestCase, TestConfig):
         messages = self.responder.messages
         assert not messages
 
+    async def test_create_response(self):
+        conn_rec = ConnectionRecord(state=ConnectionRecord.STATE_REQUEST)
+
+        with async_mock.patch.object(
+            ConnectionRecord, "log_state", autospec=True
+        ) as mock_conn_log_state, async_mock.patch.object(
+            ConnectionRecord, "retrieve_request", autospec=True
+        ) as mock_conn_retrieve_request, async_mock.patch.object(
+            ConnectionRecord, "save", autospec=True
+        ) as mock_conn_save, async_mock.patch.object(
+            ConnectionResponse, "sign_field", autospec=True
+        ) as mock_sign:
+            await self.manager.create_response(conn_rec, "http://10.20.30.40:5060/")
+
     async def test_create_response_bad_state(self):
         with self.assertRaises(ConnectionManagerError):
             await self.manager.create_response(
@@ -788,7 +802,11 @@ class TestConnectionManager(AsyncTestCase, TestConfig):
             assert await self.manager.resolve_inbound_connection(receipt)
 
     async def test_create_did_document(self):
-        did_info = DIDInfo(self.test_did, self.test_verkey, None,)
+        did_info = DIDInfo(
+            self.test_did,
+            self.test_verkey,
+            None,
+        )
 
         mock_conn = async_mock.MagicMock()
         mock_conn.connection_id = "dummy"
@@ -814,7 +832,11 @@ class TestConnectionManager(AsyncTestCase, TestConfig):
             )
 
     async def test_create_did_document_not_active(self):
-        did_info = DIDInfo(self.test_did, self.test_verkey, None,)
+        did_info = DIDInfo(
+            self.test_did,
+            self.test_verkey,
+            None,
+        )
 
         mock_conn = async_mock.MagicMock()
         mock_conn.connection_id = "dummy"
@@ -835,7 +857,11 @@ class TestConnectionManager(AsyncTestCase, TestConfig):
                 )
 
     async def test_create_did_document_no_services(self):
-        did_info = DIDInfo(self.test_did, self.test_verkey, None,)
+        did_info = DIDInfo(
+            self.test_did,
+            self.test_verkey,
+            None,
+        )
 
         mock_conn = async_mock.MagicMock()
         mock_conn.connection_id = "dummy"
@@ -863,7 +889,11 @@ class TestConnectionManager(AsyncTestCase, TestConfig):
                 )
 
     async def test_create_did_document_no_service_endpoint(self):
-        did_info = DIDInfo(self.test_did, self.test_verkey, None,)
+        did_info = DIDInfo(
+            self.test_did,
+            self.test_verkey,
+            None,
+        )
 
         mock_conn = async_mock.MagicMock()
         mock_conn.connection_id = "dummy"
@@ -894,7 +924,11 @@ class TestConnectionManager(AsyncTestCase, TestConfig):
                 )
 
     async def test_create_did_document_no_service_recip_keys(self):
-        did_info = DIDInfo(self.test_did, self.test_verkey, None,)
+        did_info = DIDInfo(
+            self.test_did,
+            self.test_verkey,
+            None,
+        )
 
         mock_conn = async_mock.MagicMock()
         mock_conn.connection_id = "dummy"
@@ -933,7 +967,11 @@ class TestConnectionManager(AsyncTestCase, TestConfig):
                 )
 
     async def test_did_key_storage(self):
-        did_info = DIDInfo(self.test_did, self.test_verkey, None,)
+        did_info = DIDInfo(
+            self.test_did,
+            self.test_verkey,
+            None,
+        )
 
         did_doc = self.make_did_doc(
             did=self.test_target_did, verkey=self.test_target_verkey
@@ -977,7 +1015,8 @@ class TestConnectionManager(AsyncTestCase, TestConfig):
         )
 
         targets = await self.manager.get_connection_targets(
-            connection_id=None, connection=mock_conn,
+            connection_id=None,
+            connection=mock_conn,
         )
         assert len(targets) == 1
         target = targets[0]
@@ -990,7 +1029,8 @@ class TestConnectionManager(AsyncTestCase, TestConfig):
 
         # Next pass: exercise cache
         targets = await self.manager.get_connection_targets(
-            connection_id=None, connection=mock_conn,
+            connection_id=None,
+            connection=mock_conn,
         )
         assert len(targets) == 1
         target = targets[0]
@@ -1038,7 +1078,8 @@ class TestConnectionManager(AsyncTestCase, TestConfig):
             mock_conn_rec_retrieve_by_id.return_value = mock_conn
             mock_conn_target_ser.return_value = {"serialized": "value"}
             targets = await self.manager.get_connection_targets(
-                connection_id="dummy", connection=None,
+                connection_id="dummy",
+                connection=None,
             )
             assert len(targets) == 1
             target = targets[0]
@@ -1081,7 +1122,8 @@ class TestConnectionManager(AsyncTestCase, TestConfig):
         )
 
         targets = await self.manager.get_connection_targets(
-            connection_id=None, connection=mock_conn,
+            connection_id=None,
+            connection=mock_conn,
         )
         assert len(targets) == 1
         target = targets[0]
