@@ -47,7 +47,8 @@ class TestIntroductionRoutes(AsyncTestCase):
         )
 
         conn_rec_init = ConnectionRecord(
-            connection_id=None, state=ConnectionRecord.STATE_INACTIVE,
+            connection_id=None,
+            state=ConnectionRecord.STATE_INACTIVE,
         )
         await conn_rec_init.save(self.context)
         assert conn_rec_init._id
@@ -66,7 +67,8 @@ class TestIntroductionRoutes(AsyncTestCase):
         )
 
         conn_rec_init = ConnectionRecord(
-            connection_id=None, state=ConnectionRecord.STATE_ACTIVE,
+            connection_id=None,
+            state=ConnectionRecord.STATE_ACTIVE,
         )
         await conn_rec_init.save(self.context)
         assert conn_rec_init._id
@@ -85,13 +87,15 @@ class TestIntroductionRoutes(AsyncTestCase):
         )
 
         conn_rec_init = ConnectionRecord(
-            connection_id=None, state=ConnectionRecord.STATE_ACTIVE,
+            connection_id=None,
+            state=ConnectionRecord.STATE_ACTIVE,
         )
         await conn_rec_init.save(self.context)
         assert conn_rec_init._id
 
         conn_rec_target = ConnectionRecord(
-            connection_id=None, state=ConnectionRecord.STATE_INACTIVE,
+            connection_id=None,
+            state=ConnectionRecord.STATE_INACTIVE,
         )
         await conn_rec_target.save(self.context)
         assert conn_rec_target._id
@@ -111,13 +115,15 @@ class TestIntroductionRoutes(AsyncTestCase):
         start_responder = MockResponder()
 
         conn_rec_init = ConnectionRecord(
-            connection_id=None, state=ConnectionRecord.STATE_ACTIVE,
+            connection_id=None,
+            state=ConnectionRecord.STATE_ACTIVE,
         )
         await conn_rec_init.save(self.context)
         assert conn_rec_init._id
 
         conn_rec_target = ConnectionRecord(
-            connection_id=None, state=ConnectionRecord.STATE_ACTIVE,
+            connection_id=None,
+            state=ConnectionRecord.STATE_ACTIVE,
         )
         await conn_rec_target.save(self.context)
         assert conn_rec_target._id
@@ -179,7 +185,8 @@ class TestIntroductionRoutes(AsyncTestCase):
         )
 
         conn_rec_target = ConnectionRecord(
-            connection_id=None, state=ConnectionRecord.STATE_ACTIVE,
+            connection_id=None,
+            state=ConnectionRecord.STATE_ACTIVE,
         )
         await conn_rec_target.save(self.context)
         assert conn_rec_target._id
