@@ -13,6 +13,7 @@ from ....storage.error import StorageNotFoundError
 
 from .manager import OutOfBandManager, OutOfBandManagerError
 from .messages.invitation import InvitationSchema
+from .message_types import SPEC_URI
 
 
 LOGGER = logging.getLogger(__name__)
@@ -39,7 +40,8 @@ class InvitationReceiveRequestSchema(InvitationSchema):
 
 
 @docs(
-    tags=["out-of-band"], summary="Create a new connection invitation",
+    tags=["out-of-band"],
+    summary="Create a new connection invitation",
 )
 @request_schema(InvitationCreateRequestSchema())
 async def invitation_create(request: web.BaseRequest):
@@ -77,7 +79,8 @@ async def invitation_create(request: web.BaseRequest):
 
 
 @docs(
-    tags=["out-of-band"], summary="Create a new connection invitation",
+    tags=["out-of-band"],
+    summary="Create a new connection invitation",
 )
 @request_schema(InvitationReceiveRequestSchema())
 async def invitation_receive(request: web.BaseRequest):
@@ -125,10 +128,7 @@ def post_process_routes(app: web.Application):
             "description": "Out-of-band connections",
             "externalDocs": {
                 "description": "Design",
-                "url": (
-                    "https://github.com/hyperledger/aries-rfcs/tree/"
-                    "2da7fc4ee043effa3a9960150e7ba8c9a4628b68/features/0434-outofband"
-                ),
+                "url": SPEC_URI,
             },
         }
     )
