@@ -9,6 +9,8 @@ from ......messaging.responder import MockResponder
 from ......storage.error import StorageNotFoundError
 from ......transport.inbound.receipt import MessageReceipt
 
+from .....didcomm_prefix import DIDCommPrefix
+
 from ...messages.presentation_request import PresentationRequest
 from .. import presentation_request_handler as handler
 
@@ -104,11 +106,19 @@ class TestPresentationRequestHandler(AsyncTestCase):
                 "requested_attributes": {
                     "0_favourite_uuid": {
                         "name": "favourite",
-                        "restrictions": [{"cred_def_id": CD_ID,}],
+                        "restrictions": [
+                            {
+                                "cred_def_id": CD_ID,
+                            }
+                        ],
                     },
                     "1_icon_uuid": {
                         "name": "icon",
-                        "restrictions": [{"cred_def_id": CD_ID,}],
+                        "restrictions": [
+                            {
+                                "cred_def_id": CD_ID,
+                            }
+                        ],
                     },
                 },
                 "requested_predicates": {},
@@ -118,9 +128,8 @@ class TestPresentationRequestHandler(AsyncTestCase):
         px_rec_instance = handler.V10PresentationExchange(
             presentation_proposal_dict={
                 "presentation_proposal": {
-                    "@type": (
-                        "did:sov:BzCbsNYhMrjHiqZDTUASHg;"
-                        "spec/present-proof/1.0/presentation-preview"
+                    "@type": DIDCommPrefix.qualify_current(
+                        "present-proof/1.0/presentation-preview"
                     ),
                     "attributes": [
                         {"name": "favourite", "cred_def_id": CD_ID, "value": "potato"},
@@ -140,8 +149,10 @@ class TestPresentationRequestHandler(AsyncTestCase):
             handler, "BaseHolder", autospec=True
         ) as mock_holder:
 
-            mock_holder.get_credentials_for_presentation_request_by_referent = async_mock.CoroutineMock(
-                return_value=[{"cred_info": {"referent": "dummy"}}]
+            mock_holder.get_credentials_for_presentation_request_by_referent = (
+                async_mock.CoroutineMock(
+                    return_value=[{"cred_info": {"referent": "dummy"}}]
+                )
             )
             request_context.inject = async_mock.CoroutineMock(return_value=mock_holder)
 
@@ -185,11 +196,19 @@ class TestPresentationRequestHandler(AsyncTestCase):
                 "requested_attributes": {
                     "0_favourite_uuid": {
                         "name": "favourite",
-                        "restrictions": [{"cred_def_id": CD_ID,}],
+                        "restrictions": [
+                            {
+                                "cred_def_id": CD_ID,
+                            }
+                        ],
                     },
                     "1_icon_uuid": {
                         "name": "icon",
-                        "restrictions": [{"cred_def_id": CD_ID,}],
+                        "restrictions": [
+                            {
+                                "cred_def_id": CD_ID,
+                            }
+                        ],
                     },
                 },
                 "requested_predicates": {},
@@ -206,11 +225,13 @@ class TestPresentationRequestHandler(AsyncTestCase):
             handler, "BaseHolder", autospec=True
         ) as mock_holder:
 
-            mock_holder.get_credentials_for_presentation_request_by_referent = async_mock.CoroutineMock(
-                return_value=[
-                    {"cred_info": {"referent": "dummy-0"}},
-                    {"cred_info": {"referent": "dummy-1"}},
-                ]
+            mock_holder.get_credentials_for_presentation_request_by_referent = (
+                async_mock.CoroutineMock(
+                    return_value=[
+                        {"cred_info": {"referent": "dummy-0"}},
+                        {"cred_info": {"referent": "dummy-1"}},
+                    ]
+                )
             )
             request_context.inject = async_mock.CoroutineMock(return_value=mock_holder)
 
@@ -256,8 +277,12 @@ class TestPresentationRequestHandler(AsyncTestCase):
                     "0_score_GE_uuid": {
                         "name": "score",
                         "p_type": ">=",
-                        "p_value": "1000000",
-                        "restrictions": [{"cred_def_id": CD_ID,}],
+                        "p_value": 1000000,
+                        "restrictions": [
+                            {
+                                "cred_def_id": CD_ID,
+                            }
+                        ],
                     }
                 },
             }
@@ -273,8 +298,8 @@ class TestPresentationRequestHandler(AsyncTestCase):
             handler, "BaseHolder", autospec=True
         ) as mock_holder:
 
-            mock_holder.get_credentials_for_presentation_request_by_referent = async_mock.CoroutineMock(
-                return_value=[]
+            mock_holder.get_credentials_for_presentation_request_by_referent = (
+                async_mock.CoroutineMock(return_value=[])
             )
             request_context.inject = async_mock.CoroutineMock(return_value=mock_holder)
 
@@ -316,8 +341,12 @@ class TestPresentationRequestHandler(AsyncTestCase):
                     "0_score_GE_uuid": {
                         "name": "score",
                         "p_type": ">=",
-                        "p_value": "1000000",
-                        "restrictions": [{"cred_def_id": CD_ID,}],
+                        "p_value": 1000000,
+                        "restrictions": [
+                            {
+                                "cred_def_id": CD_ID,
+                            }
+                        ],
                     }
                 },
             }
@@ -333,8 +362,10 @@ class TestPresentationRequestHandler(AsyncTestCase):
             handler, "BaseHolder", autospec=True
         ) as mock_holder:
 
-            mock_holder.get_credentials_for_presentation_request_by_referent = async_mock.CoroutineMock(
-                return_value=[{"cred_info": {"referent": "dummy-0"}}]
+            mock_holder.get_credentials_for_presentation_request_by_referent = (
+                async_mock.CoroutineMock(
+                    return_value=[{"cred_info": {"referent": "dummy-0"}}]
+                )
             )
             request_context.inject = async_mock.CoroutineMock(return_value=mock_holder)
 
@@ -380,8 +411,12 @@ class TestPresentationRequestHandler(AsyncTestCase):
                     "0_score_GE_uuid": {
                         "name": "score",
                         "p_type": ">=",
-                        "p_value": "1000000",
-                        "restrictions": [{"cred_def_id": CD_ID,}],
+                        "p_value": 1000000,
+                        "restrictions": [
+                            {
+                                "cred_def_id": CD_ID,
+                            }
+                        ],
                     }
                 },
             }
@@ -397,11 +432,13 @@ class TestPresentationRequestHandler(AsyncTestCase):
             handler, "BaseHolder", autospec=True
         ) as mock_holder:
 
-            mock_holder.get_credentials_for_presentation_request_by_referent = async_mock.CoroutineMock(
-                return_value=[
-                    {"cred_info": {"referent": "dummy-0"}},
-                    {"cred_info": {"referent": "dummy-1"}},
-                ]
+            mock_holder.get_credentials_for_presentation_request_by_referent = (
+                async_mock.CoroutineMock(
+                    return_value=[
+                        {"cred_info": {"referent": "dummy-0"}},
+                        {"cred_info": {"referent": "dummy-1"}},
+                    ]
+                )
             )
             request_context.inject = async_mock.CoroutineMock(return_value=mock_holder)
 
@@ -445,11 +482,19 @@ class TestPresentationRequestHandler(AsyncTestCase):
                 "requested_attributes": {
                     "0_favourite_uuid": {
                         "name": "favourite",
-                        "restrictions": [{"cred_def_id": CD_ID,}],
+                        "restrictions": [
+                            {
+                                "cred_def_id": CD_ID,
+                            }
+                        ],
                     },
                     "1_icon_uuid": {
                         "name": "icon",
-                        "restrictions": [{"cred_def_id": CD_ID,}],
+                        "restrictions": [
+                            {
+                                "cred_def_id": CD_ID,
+                            }
+                        ],
                     },
                 },
                 "requested_predicates": {},
@@ -459,9 +504,8 @@ class TestPresentationRequestHandler(AsyncTestCase):
         px_rec_instance = handler.V10PresentationExchange(
             presentation_proposal_dict={
                 "presentation_proposal": {
-                    "@type": (
-                        "did:sov:BzCbsNYhMrjHiqZDTUASHg;"
-                        "spec/present-proof/1.0/presentation-preview"
+                    "@type": DIDCommPrefix.qualify_current(
+                        "present-proof/1.0/presentation-preview"
                     ),
                     "attributes": [
                         {"name": "favourite", "cred_def_id": CD_ID, "value": "potato"},
@@ -481,42 +525,44 @@ class TestPresentationRequestHandler(AsyncTestCase):
             handler, "BaseHolder", autospec=True
         ) as mock_holder:
 
-            mock_holder.get_credentials_for_presentation_request_by_referent = async_mock.CoroutineMock(
-                return_value=[
-                    {
-                        "cred_info": {
-                            "referent": "dummy-0",
-                            "cred_def_id": CD_ID,
-                            "attrs": {
-                                "ident": "zero",
-                                "favourite": "potato",
-                                "icon": "cG90YXRv",
-                            },
-                        }
-                    },
-                    {
-                        "cred_info": {
-                            "referent": "dummy-1",
-                            "cred_def_id": CD_ID,
-                            "attrs": {
-                                "ident": "one",
-                                "favourite": "spud",
-                                "icon": "c3B1ZA==",
-                            },
-                        }
-                    },
-                    {
-                        "cred_info": {
-                            "referent": "dummy-2",
-                            "cred_def_id": CD_ID,
-                            "attrs": {
-                                "ident": "two",
-                                "favourite": "patate",
-                                "icon": "cGF0YXRl",
-                            },
-                        }
-                    },
-                ]
+            mock_holder.get_credentials_for_presentation_request_by_referent = (
+                async_mock.CoroutineMock(
+                    return_value=[
+                        {
+                            "cred_info": {
+                                "referent": "dummy-0",
+                                "cred_def_id": CD_ID,
+                                "attrs": {
+                                    "ident": "zero",
+                                    "favourite": "potato",
+                                    "icon": "cG90YXRv",
+                                },
+                            }
+                        },
+                        {
+                            "cred_info": {
+                                "referent": "dummy-1",
+                                "cred_def_id": CD_ID,
+                                "attrs": {
+                                    "ident": "one",
+                                    "favourite": "spud",
+                                    "icon": "c3B1ZA==",
+                                },
+                            }
+                        },
+                        {
+                            "cred_info": {
+                                "referent": "dummy-2",
+                                "cred_def_id": CD_ID,
+                                "attrs": {
+                                    "ident": "two",
+                                    "favourite": "patate",
+                                    "icon": "cGF0YXRl",
+                                },
+                            }
+                        },
+                    ]
+                )
             )
             request_context.inject = async_mock.CoroutineMock(return_value=mock_holder)
 
@@ -560,7 +606,11 @@ class TestPresentationRequestHandler(AsyncTestCase):
                 "requested_attributes": {
                     "0_favourite_uuid": {
                         "name": "favourite",
-                        "restrictions": [{"cred_def_id": CD_ID,}],
+                        "restrictions": [
+                            {
+                                "cred_def_id": CD_ID,
+                            }
+                        ],
                     }
                 },
                 "requested_predicates": {},
@@ -570,9 +620,8 @@ class TestPresentationRequestHandler(AsyncTestCase):
         px_rec_instance = handler.V10PresentationExchange(
             presentation_proposal_dict={
                 "presentation_proposal": {
-                    "@type": (
-                        "did:sov:BzCbsNYhMrjHiqZDTUASHg;"
-                        "spec/present-proof/1.0/presentation-preview"
+                    "@type": DIDCommPrefix.qualify_current(
+                        "present-proof/1.0/presentation-preview"
                     ),
                     "attributes": [
                         {"name": "favourite", "cred_def_id": CD_ID, "value": "potato"}
@@ -591,7 +640,7 @@ class TestPresentationRequestHandler(AsyncTestCase):
             handler, "BaseHolder", autospec=True
         ) as mock_holder:
 
-            mock_holder.get_credentials_for_presentation_request_by_referent = async_mock.CoroutineMock(
+            by_reft = async_mock.CoroutineMock(
                 return_value=[
                     {
                         "cred_info": {
@@ -619,6 +668,7 @@ class TestPresentationRequestHandler(AsyncTestCase):
                     },
                 ]
             )
+            mock_holder.get_credentials_for_presentation_request_by_referent = by_reft
             request_context.inject = async_mock.CoroutineMock(return_value=mock_holder)
 
             mock_pres_ex_rec.return_value = px_rec_instance
