@@ -1,6 +1,6 @@
 """An object for containing information on an individual route."""
 
-from marshmallow import fields
+from marshmallow import EXCLUDE, fields
 
 from .....messaging.models.base import BaseModel, BaseModelSchema
 
@@ -30,7 +30,7 @@ class RouteRecord(BaseModel):
             recipient_key: The recipient verkey of the route
 
         """
-        super(RouteRecord, self).__init__(**kwargs)
+        super().__init__(**kwargs)
         self.record_id = record_id
         self.connection_id = connection_id
         self.recipient_key = recipient_key
@@ -44,7 +44,8 @@ class RouteRecordSchema(BaseModelSchema):
     class Meta:
         """RouteRecordSchema metadata."""
 
-        model_class = "RouteRecord"
+        model_class = RouteRecord
+        unknown = EXCLUDE
 
     record_id = fields.Str(required=False)
     connection_id = fields.Str(required=True)
