@@ -25,7 +25,7 @@ class StorageProvider(BaseProvider):
         wallet_type = settings.get_value("wallet.type", default="basic").lower()
         storage_default_type = "indy" if wallet_type == "indy" else "basic"
         storage_type = settings.get_value(
-            "storage.type", default=storage_default_type
+            "storage_type", default=storage_default_type
         ).lower()
         storage_class = self.STORAGE_TYPES.get(storage_type, storage_type)
         storage = ClassLoader.load_class(storage_class)(wallet)
