@@ -9,6 +9,7 @@ from ...ledger.base import BaseLedger
 from ...wallet.base import BaseWallet, DIDInfo
 
 from .. import routes as test_module
+from ..did_posture import DIDPosture
 
 
 class TestWalletRoutes(AsyncTestCase):
@@ -22,6 +23,8 @@ class TestWalletRoutes(AsyncTestCase):
         }
         self.test_did = "did"
         self.test_verkey = "verkey"
+        self.test_posted_did = "posted-did"
+        self.test_posted_verkey = "posted-verkey"
 
     async def test_missing_wallet(self):
         request = async_mock.MagicMock()
@@ -47,34 +50,46 @@ class TestWalletRoutes(AsyncTestCase):
             await test_module.wallet_get_did_endpoint(request)
 
     def test_format_did_info(self):
-        did_info = DIDInfo(self.test_did, self.test_verkey, {})
+        did_info = DIDInfo(
+            self.test_did, self.test_verkey, DIDPosture.WALLET_ONLY.metadata
+        )
         result = test_module.format_did_info(did_info)
         assert (
             result["did"] == self.test_did
             and result["verkey"] == self.test_verkey
-            and result["public"] == "false"
+            and result["posture"] == DIDPosture.WALLET_ONLY.moniker
+        )
+
+        did_info = DIDInfo(
+            self.test_did, self.test_verkey, {"posted": True, "public": True}
         )
-        did_info = DIDInfo(self.test_did, self.test_verkey, {"public": True})
         result = test_module.format_did_info(did_info)
-        assert result["public"] == "true"
+        assert result["posture"] == DIDPosture.PUBLIC.moniker
+
+        did_info = DIDInfo(
+            self.test_did, self.test_verkey, {"posted": True, "public": False}
+        )
+        result = test_module.format_did_info(did_info)
+        assert result["posture"] == DIDPosture.POSTED.moniker
 
     async def test_create_did(self):
         request = async_mock.MagicMock()
         request.app = self.app
         with async_mock.patch.object(
             test_module.web, "json_response", async_mock.Mock()
-        ) as json_response, async_mock.patch.object(
-            test_module, "format_did_info", async_mock.Mock()
-        ) as format_did_info:
+        ) as json_response:
             self.wallet.create_local_did.return_value = DIDInfo(
-                self.test_did, self.test_verkey, {}
+                self.test_did, self.test_verkey, DIDPosture.WALLET_ONLY.metadata
             )
             result = await test_module.wallet_create_did(request)
-            format_did_info.assert_called_once_with(
-                self.wallet.create_local_did.return_value
-            )
             json_response.assert_called_once_with(
-                {"result": format_did_info.return_value}
+                {
+                    "result": {
+                        "did": self.test_did,
+                        "verkey": self.test_verkey,
+                        "posture": DIDPosture.WALLET_ONLY.moniker,
+                    }
+                }
             )
             assert result is json_response.return_value
 
@@ -91,19 +106,33 @@ class TestWalletRoutes(AsyncTestCase):
         request.query = {}
         with async_mock.patch.object(
             test_module.web, "json_response", async_mock.Mock()
-        ) as json_response, async_mock.patch.object(
-            test_module, "format_did_info", async_mock.Mock()
-        ) as format_did_info:
+        ) as json_response:  # , async_mock.patch.object(
             self.wallet.get_local_dids.return_value = [
-                DIDInfo(self.test_did, self.test_verkey, {})
+                DIDInfo(
+                    self.test_did, self.test_verkey, DIDPosture.WALLET_ONLY.metadata
+                ),
+                DIDInfo(
+                    self.test_posted_did,
+                    self.test_posted_verkey,
+                    DIDPosture.POSTED.metadata,
+                ),
             ]
-            format_did_info.return_value = {"did": self.test_did}
             result = await test_module.wallet_did_list(request)
-            format_did_info.assert_called_once_with(
-                self.wallet.get_local_dids.return_value[0]
-            )
             json_response.assert_called_once_with(
-                {"results": [format_did_info.return_value]}
+                {
+                    "results": [
+                        {
+                            "did": self.test_posted_did,
+                            "verkey": self.test_posted_verkey,
+                            "posture": DIDPosture.POSTED.moniker,
+                        },
+                        {
+                            "did": self.test_did,
+                            "verkey": self.test_verkey,
+                            "posture": DIDPosture.WALLET_ONLY.moniker,
+                        },
+                    ]
+                }
             )
             assert json_response.return_value is json_response()
             assert result is json_response.return_value
@@ -111,22 +140,66 @@ class TestWalletRoutes(AsyncTestCase):
     async def test_did_list_filter_public(self):
         request = async_mock.MagicMock()
         request.app = self.app
-        request.query = {"public": "true"}
+        request.query = {"posture": DIDPosture.PUBLIC.moniker}
         with async_mock.patch.object(
             test_module.web, "json_response", async_mock.Mock()
-        ) as json_response, async_mock.patch.object(
-            test_module, "format_did_info", async_mock.Mock()
-        ) as format_did_info:
+        ) as json_response:
             self.wallet.get_public_did.return_value = DIDInfo(
-                self.test_did, self.test_verkey, {}
+                self.test_did, self.test_verkey, DIDPosture.PUBLIC.metadata
             )
-            format_did_info.return_value = {"did": self.test_did}
+            self.wallet.get_posted_dids.return_value = [
+                DIDInfo(
+                    self.test_posted_did,
+                    self.test_posted_verkey,
+                    DIDPosture.POSTED.metadata,
+                )
+            ]
             result = await test_module.wallet_did_list(request)
-            format_did_info.assert_called_once_with(
-                self.wallet.get_public_did.return_value
-            )
             json_response.assert_called_once_with(
-                {"results": [format_did_info.return_value]}
+                {
+                    "results": [
+                        {
+                            "did": self.test_did,
+                            "verkey": self.test_verkey,
+                            "posture": DIDPosture.PUBLIC.moniker,
+                        }
+                    ]
+                }
+            )
+            assert json_response.return_value is json_response()
+            assert result is json_response.return_value
+
+    async def test_did_list_filter_posted(self):
+        request = async_mock.MagicMock()
+        request.app = self.app
+        request.query = {"posture": DIDPosture.POSTED.moniker}
+        with async_mock.patch.object(
+            test_module.web, "json_response", async_mock.Mock()
+        ) as json_response:
+            self.wallet.get_public_did.return_value = DIDInfo(
+                self.test_did, self.test_verkey, DIDPosture.PUBLIC.metadata
+            )
+            self.wallet.get_posted_dids.return_value = [
+                DIDInfo(
+                    self.test_posted_did,
+                    self.test_posted_verkey,
+                    {
+                        "posted": True,
+                        "public": False,
+                    },
+                )
+            ]
+            result = await test_module.wallet_did_list(request)
+            json_response.assert_called_once_with(
+                {
+                    "results": [
+                        {
+                            "did": self.test_posted_did,
+                            "verkey": self.test_posted_verkey,
+                            "posture": DIDPosture.POSTED.moniker,
+                        }
+                    ]
+                }
             )
             assert json_response.return_value is json_response()
             assert result is json_response.return_value
@@ -137,19 +210,21 @@ class TestWalletRoutes(AsyncTestCase):
         request.query = {"did": self.test_did}
         with async_mock.patch.object(
             test_module.web, "json_response", async_mock.Mock()
-        ) as json_response, async_mock.patch.object(
-            test_module, "format_did_info", async_mock.Mock()
-        ) as format_did_info:
+        ) as json_response:
             self.wallet.get_local_did.return_value = DIDInfo(
-                self.test_did, self.test_verkey, {}
+                self.test_did, self.test_verkey, DIDPosture.WALLET_ONLY.metadata
             )
-            format_did_info.return_value = {"did": self.test_did}
             result = await test_module.wallet_did_list(request)
-            format_did_info.assert_called_once_with(
-                self.wallet.get_local_did.return_value
-            )
             json_response.assert_called_once_with(
-                {"results": [format_did_info.return_value]}
+                {
+                    "results": [
+                        {
+                            "did": self.test_did,
+                            "verkey": self.test_verkey,
+                            "posture": DIDPosture.WALLET_ONLY.moniker,
+                        }
+                    ]
+                }
             )
             assert json_response.return_value is json_response()
             assert result is json_response.return_value
@@ -173,19 +248,21 @@ class TestWalletRoutes(AsyncTestCase):
         request.query = {"verkey": self.test_verkey}
         with async_mock.patch.object(
             test_module.web, "json_response", async_mock.Mock()
-        ) as json_response, async_mock.patch.object(
-            test_module, "format_did_info", async_mock.Mock()
-        ) as format_did_info:
+        ) as json_response:
             self.wallet.get_local_did_for_verkey.return_value = DIDInfo(
-                self.test_did, self.test_verkey, {}
+                self.test_did, self.test_verkey, DIDPosture.WALLET_ONLY.metadata
             )
-            format_did_info.return_value = {"did": self.test_did}
             result = await test_module.wallet_did_list(request)
-            format_did_info.assert_called_once_with(
-                self.wallet.get_local_did_for_verkey.return_value
-            )
             json_response.assert_called_once_with(
-                {"results": [format_did_info.return_value]}
+                {
+                    "results": [
+                        {
+                            "did": self.test_did,
+                            "verkey": self.test_verkey,
+                            "posture": DIDPosture.WALLET_ONLY.moniker,
+                        }
+                    ]
+                }
             )
             assert json_response.return_value is json_response()
             assert result is json_response.return_value
@@ -208,18 +285,19 @@ class TestWalletRoutes(AsyncTestCase):
         request.app = self.app
         with async_mock.patch.object(
             test_module.web, "json_response", async_mock.Mock()
-        ) as json_response, async_mock.patch.object(
-            test_module, "format_did_info", async_mock.Mock()
-        ) as format_did_info:
+        ) as json_response:
             self.wallet.get_public_did.return_value = DIDInfo(
-                self.test_did, self.test_verkey, {}
+                self.test_did, self.test_verkey, DIDPosture.PUBLIC.metadata
             )
             result = await test_module.wallet_get_public_did(request)
-            format_did_info.assert_called_once_with(
-                self.wallet.get_public_did.return_value
-            )
             json_response.assert_called_once_with(
-                {"result": format_did_info.return_value}
+                {
+                    "result": {
+                        "did": self.test_did,
+                        "verkey": self.test_verkey,
+                        "posture": DIDPosture.PUBLIC.moniker,
+                    }
+                }
             )
             assert result is json_response.return_value
 
@@ -244,19 +322,20 @@ class TestWalletRoutes(AsyncTestCase):
 
         with async_mock.patch.object(
             test_module.web, "json_response", async_mock.Mock()
-        ) as json_response, async_mock.patch.object(
-            test_module, "format_did_info", async_mock.Mock()
-        ) as format_did_info:
-            self.wallet.get_public_did.return_value = DIDInfo(
-                self.test_did, self.test_verkey, {}
+        ) as json_response:
+            self.wallet.set_public_did.return_value = DIDInfo(
+                self.test_did, self.test_verkey, DIDPosture.PUBLIC.metadata
             )
             result = await test_module.wallet_set_public_did(request)
             self.wallet.set_public_did.assert_awaited_once_with(request.query["did"])
-            format_did_info.assert_called_once_with(
-                self.wallet.set_public_did.return_value
-            )
             json_response.assert_called_once_with(
-                {"result": format_did_info.return_value}
+                {
+                    "result": {
+                        "did": self.test_did,
+                        "verkey": self.test_verkey,
+                        "posture": DIDPosture.PUBLIC.moniker,
+                    }
+                }
             )
             assert result is json_response.return_value
 
@@ -319,11 +398,9 @@ class TestWalletRoutes(AsyncTestCase):
 
         with async_mock.patch.object(
             test_module.web, "json_response", async_mock.Mock()
-        ) as json_response, async_mock.patch.object(
-            test_module, "format_did_info", async_mock.Mock()
-        ) as format_did_info:
+        ) as json_response:
             self.wallet.get_public_did.return_value = DIDInfo(
-                self.test_did, self.test_verkey, {}
+                self.test_did, self.test_verkey, DIDPosture.PUBLIC.metadata
             )
             self.wallet.set_public_did.side_effect = test_module.WalletError()
             with self.assertRaises(test_module.web.HTTPBadRequest):
@@ -343,11 +420,9 @@ class TestWalletRoutes(AsyncTestCase):
 
         with async_mock.patch.object(
             test_module.web, "json_response", async_mock.Mock()
-        ) as json_response, async_mock.patch.object(
-            test_module, "format_did_info", async_mock.Mock()
-        ) as format_did_info:
+        ) as json_response:
             self.wallet.get_public_did.return_value = DIDInfo(
-                self.test_did, self.test_verkey, {}
+                self.test_did, self.test_verkey, DIDPosture.PUBLIC.metadata
             )
             self.wallet.set_public_did.side_effect = test_module.WalletNotFoundError()
             with self.assertRaises(test_module.web.HTTPNotFound):
@@ -367,19 +442,20 @@ class TestWalletRoutes(AsyncTestCase):
 
         with async_mock.patch.object(
             test_module.web, "json_response", async_mock.Mock()
-        ) as json_response, async_mock.patch.object(
-            test_module, "format_did_info", async_mock.Mock()
-        ) as format_did_info:
-            self.wallet.get_public_did.return_value = DIDInfo(
-                self.test_did, self.test_verkey, {}
+        ) as json_response:
+            self.wallet.set_public_did.return_value = DIDInfo(
+                self.test_did, self.test_verkey, DIDPosture.PUBLIC.metadata
             )
             result = await test_module.wallet_set_public_did(request)
             self.wallet.set_public_did.assert_awaited_once_with(request.query["did"])
-            format_did_info.assert_called_once_with(
-                self.wallet.set_public_did.return_value
-            )
             json_response.assert_called_once_with(
-                {"result": format_did_info.return_value}
+                {
+                    "result": {
+                        "did": self.test_did,
+                        "verkey": self.test_verkey,
+                        "posture": DIDPosture.PUBLIC.moniker,
+                    }
+                }
             )
             assert result is json_response.return_value
 
@@ -405,7 +481,7 @@ class TestWalletRoutes(AsyncTestCase):
             {"public": False, "endpoint": "http://old-endpoint.ca"},
         )
         self.wallet.get_public_did.return_value = DIDInfo(
-            self.test_did, self.test_verkey, {}
+            self.test_did, self.test_verkey, DIDPosture.PUBLIC.metadata
         )
 
         with async_mock.patch.object(
@@ -430,7 +506,7 @@ class TestWalletRoutes(AsyncTestCase):
             {"public": False, "endpoint": "http://old-endpoint.ca"},
         )
         self.wallet.get_public_did.return_value = DIDInfo(
-            self.test_did, self.test_verkey, {}
+            self.test_did, self.test_verkey, DIDPosture.PUBLIC.metadata
         )
         self.wallet.set_did_endpoint.side_effect = test_module.LedgerConfigError()
 
@@ -577,7 +653,7 @@ class TestWalletRoutes(AsyncTestCase):
             await test_module.wallet_rotate_did_keypair(request)
 
         self.wallet.get_local_did = async_mock.CoroutineMock(
-            return_value=DIDInfo("did", "verkey", {"public": True})
+            return_value=DIDInfo("did", "verkey", {"posted": True, "public": True})
         )
         with self.assertRaises(test_module.web.HTTPBadRequest):
             await test_module.wallet_rotate_did_keypair(request)
